@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
+    SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -39,8 +39,15 @@ QString CustomLoggingCategoryProxyModel::filterText() const
 void CustomLoggingCategoryProxyModel::setFilterText(const QString &newFilterText)
 {
     if (mFilterText != newFilterText) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        beginFilterChange();
+#endif
         mFilterText = newFilterText;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
         invalidateFilter();
+#endif
         Q_EMIT filterTextChanged();
     }
 }
