@@ -36,8 +36,15 @@ QString KDEApplicationLoggingCategoryProxyModel::filterText() const
 void KDEApplicationLoggingCategoryProxyModel::setFilterText(const QString &newFilterText)
 {
     if (mFilterText != newFilterText) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        beginFilterChange();
+#endif
         mFilterText = newFilterText;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
         invalidateFilter();
+#endif
         Q_EMIT filterTextChanged();
     }
 }
