@@ -6,6 +6,8 @@
 */
 
 #include "kdeapplicationtreeviewgui.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "kdeapplicationtreeview.h"
 #include "model/kdeapplicationloggingcategorymodel.h"
 
@@ -21,9 +23,9 @@ KDEApplicationTreeViewGui::KDEApplicationTreeViewGui(QWidget *parent)
     LoggingCategory::List lst;
     for (int i = 0; i < 5; ++i) {
         LoggingCategory cat;
-        cat.categoryName = QStringLiteral("foo-%1").arg(i);
-        cat.identifierName = QStringLiteral("ident-%1").arg(i);
-        cat.description = QStringLiteral("desc-%1").arg(i);
+        cat.categoryName = u"foo-%1"_s.arg(i);
+        cat.identifierName = u"ident-%1"_s.arg(i);
+        cat.description = u"desc-%1"_s.arg(i);
         cat.loggingType = static_cast<LoggingCategory::LoggingType>(i);
         cat.enabled = (i % 2);
         lst.append(cat);
